const PanelMenu = imports.ui.panelMenu;
const Clutter = imports.gi.Clutter;
const St = imports.gi.St;
const Main = imports.ui.main;
const Keymap = imports.gi.Gdk.Keymap.get_default();
const KeymapV38 = Clutter.get_default_backend().get_default_seat().get_keymap();
const Gio = imports.gi.Gio;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const Config = imports.misc.config;

let _version;

let indicator;

function getKeymap()
{
    if (_version < 38)
        return Keymap;

    return KeymapV38;
}

function updateState()
{
    let numlock_state = getKeymap().get_num_lock_state(), capslock_state = getKeymap().get_caps_lock_state();

    if ((indicator.actor.visible = (numlock_state | capslock_state)) == false)
        return;

    numlock_state ? indicator.numIcon.show() : indicator.numIcon.hide();
    capslock_state ? indicator.capsIcon.show() : indicator.capsIcon.hide();
}

function init()
{
    _version = parseInt(Config.PACKAGE_VERSION.split('.')[1]);
}

function enable()
{
    indicator = new PanelMenu.Button(this, St.Align.START);

    indicator.numIcon = new St.Icon({ style_class: 'system-status-icon icon-style' });
    indicator.numIcon.gicon = Gio.icon_new_for_string(Me.path + '/numlock-symbolic.png');
    indicator.capsIcon = new St.Icon({ style_class: 'system-status-icon icon-style' });
    indicator.capsIcon.gicon = Gio.icon_new_for_string(Me.path + '/capslock-symbolic.png');

    let layoutManager = new St.BoxLayout({style_class: 'icon-box'});
    layoutManager.add_child(indicator.numIcon);
    layoutManager.add_child(indicator.capsIcon);

    indicator.actor.add_actor(layoutManager);

    Main.panel.addToStatusArea('lockkeys', indicator, 2);
    indicator._keyboardStateChangedId = getKeymap().connect('state-changed', updateState);
    updateState();
}

function disable()
{
    getKeymap().disconnect(indicator._keyboardStateChangedId);
    indicator.destroy();
}
